@@ -16,6 +16,7 @@ fn test_multiline_strings() {
 	struct Test {
 		tabs: String,
 		spaces: String,
+		only_comment: String,
 	}
 
 	let t: Test = crate::from_bytes("
@@ -26,6 +27,12 @@ fn test_multiline_strings() {
 		spaces: # Comment
 		    this is so
 		    cool
+		only_comment:
+			# in string
 	").unwrap();
-	assert_eq!(t, Test{tabs: "this is so\n# No comments\ncool".into(), spaces: "this is so\ncool".into()})
+	assert_eq!(t, Test{
+		tabs: "this is so\n# No comments\ncool".into(),
+		spaces: "this is so\ncool".into(),
+		only_comment: "# in string".into(),
+	})
 }
